#!/usr/bin/env python

#****************************************************************************
# optiondefaults.py, provides initial config option values
#
# TreeLine, an information storage program
# Copyright (C) 2005, Douglas W. Bell
#
# This is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License, Version 2.  This program is
# distributed in the hope that it will be useful, but WITTHOUT ANY WARRANTY.
#*****************************************************************************

# Limits:
minPrintMargin = 0.25
maxPrintMargin = 3.0
maxNumCol = 9
maxNumLines = 200

defaultList = [\
    "# Options for TreeLine, an information storage program",
    "#",
    "# Path to an alternate plugin directory:",
    "UserPluginDir       ",
    "#",
    "##############################################################",
    "#",
    "# Keyboard key bindings",
    "#",
    "# Note that key names are case-sensitive",
    "#",
    "# Available modifiers include SHIFT, CTRL, ALT, META",
    "#",
    "# Available keys include A-Z, 0-9, F1-F12, Insert, Delete,",
    "# Home, End, PageUp, PageDown, Left, Right, Up, Down, Asterisk,",
    "# Plus, Minus, Comma, Period, Slash, Apostrophe, Semicolon,",
    "# BracketLeft, BracketRight, Equal, Backslash, Space",
    "#",
    "##############################################################",
    "#",
    "FileNew             CTRL N",
    "FileOpen            CTRL O",
    "FileSave            CTRL S",
    "FileSaveAs          ",
    "FileExport          ",
    "FilePrint           CTRL P",
    "FilePrintOpt        ",
    "FileQuit            CTRL Q",
    "#",
    "EditUndo            CTRL Z",
    "EditRedo            CTRL Y",
    "EditCut             CTRL X",
    "EditCopy            CTRL C",
    "EditCopyText        ",
    "EditPaste           CTRL V",
    "EditPasteText       ",
    "EditRename          CTRL R",
    "EditInBefore        CTRL B",
    "EditInAfter         CTRL I",
    "EditAddChild        CTRL A",
    "EditDelete          Delete",
    "EditIndent          CTRL SHIFT Right",
    "EditUnindent        CTRL SHIFT Left",
    "EditMoveUp          CTRL SHIFT Up",
    "EditMoveDown        CTRL SHIFT Down",
    "#",
    "ViewDataOutput      CTRL D",
    "ViewDataEdit        CTRL E",
    "ViewTitleList       CTRL L",
    "ViewGoTree          CTRL G",
    "ViewDataPageUp      SHIFT PageUp",
    "ViewDataPageDown    SHIFT PageDown",
    "#",
    "DataSetItemType     CTRL T",
    "DataSetDescendType  ",
    "DataConfigType      ",
    "DataCopyTypes       ",
    "DataSortChildren    ",
    "DataSortType        ",
    "DataSortTitle       ",
    "DataFilter          ",
    "DataChange          ",
    "DataNumber          ",
    "DataCategoryAdd     ",
    "DataCategoryFlat    ",
    "DataRefArrange      ",
    "DataRefFlat         ",
    "DataRefUpdate       ",
    "#",
    "ToolsExpand         CTRL Right",
    "ToolsCollapse       CTRL Left",
    "ToolsFind           CTRL F",
    "ToolsSpellCheck     ",
    "ToolsRemXLST        ",
    "ToolsGenOptions     ",
    "ToolsFileOptions    ",
    "ToolsBackColor      ",
    "ToolsTextColor      ",
    "#",
    "HelpReadMe          F1",
    "HelpAbout           ",
    "HelpPlugin          ",
    "#",
    "TreeSelectPrev      Up",
    "TreeSelectNext      Down",
    "TreeOpenItem        Right",
    "TreeCloseItem       Left",
    "TreePrevSibling     CTRL Up",
    "TreeNextSibling     CTRL Down",
    "TreeSelectParent    CTRL U",
    "TreeTop             Home",
    "TreeBottom          End",
    "TreePageUp          PageUp",
    "TreePageDown        PageDown",
    "TreeIncremSearch    Slash",
    "TreeIncremNext      F3",
    "TreeIncremPrev      SHIFT F3",
    "#",
    "##############################################################",
    "#",
    "# The following options are set from within the program,",
    "# editing here is not recommended",
    "#",
    "##############################################################",
    "#",
    "AutoFileOpen        no",
    "StartShowChildren   yes",
    "PersistTreeState    yes",
    "SaveWindowGeom      yes",
    "ClickRename         yes",
    "DragTree            yes",
    "InsertOnEnter       yes",
    "RenameNewNodes      yes",
    "OpenSearchNodes     yes",
    "ShowTreeIcons       yes",
    "EnableExecLinks     yes",
    "CompressNewFiles    no",
    "EncryptNewFiles     no",
    "HtmlNewFields       no",
    "#",
    "IndentOffset        20",
    "MaxEditLines        7",
    "UndoLevels          8",
    "AutoSaveMinutes     0",
    "#",
    "EditNumFormat       0.0000",
    "EditDateFormat      mm/dd/yyyy",
    "EditTimeFormat      H:MM",
    "#",
    "PrintPrev           yes",
    "PrintRoot           yes",
    "PrintLines          no",
    "PrintOpenOnly       no",
    "PrintKeepFirstChild yes",
    "PrintUseOutputFont  yes",
    "PrintFont           ",
    "PrintFontSize       ",
    "PrintFontBold       no",
    "PrintFontItalic     no",
    "PrintFontUnderline  no",
    "PrintFontStrikeOut  no",
    "PrintPageSize       letter",
    "PrintNumCols        1",
    "PrintColSpace       0.30",
    "PrintOffset         20",
    "HorizMargin         0.50",
    "VertMargin          0.70",
    "#",
    "BackgroundR         255",
    "BackgroundG         255",
    "BackgroundB         255",
    "ForegroundR         0",
    "ForegroundG         0",
    "ForegroundB         0",
    "#",
    "TreeFont            ",
    "TreeFontSize        ",
    "TreeFontBold        no",
    "TreeFontItalic      no",
    "TreeFontUnderline   no",
    "TreeFontStrikeOut   no",
    "OutputFont          ",
    "OutputFontSize      ",
    "OutputFontBold      no",
    "OutputFontItalic    no",
    "OutputFontUnderline no",
    "OutputFontStrikeOut no",
    "EditorFont          ",
    "EditorFontSize      ",
    "EditorFontBold      no",
    "EditorFontItalic    no",
    "EditorFontUnderline no",
    "EditorFontStrikeOut no",
    "#",
    "ToolbarData         [1,2,0,0,0],[1,2,1,0,0]",
    "RecentFile1         ",
    "RecentFile2         ",
    "RecentFile3         ",
    "RecentFile4         ",
    "TreeState1          0:0:0:0",
    "TreeState2          0:0:0:0",
    "TreeState3          0:0:0:0",
    "TreeState4          0:0:0:0",
    "SpellCheckPath      ",
    "#",
    "WindowXSize         540",
    "WindowYSize         460",
    "WindowXPos          0",
    "WindowYPos          0",
    "TreeSplitPercent    40",
    "OutputSplitPercent  20",
    "EditorSplitPercent  25",
    "TitleSplitPercent   10",
    "ActiveRightView     0",
    "PrintPrevXSize      300",
    "PrintPrevYSize      560",
    "PrintPrevXPos       0",
    "PrintPrevYPos       0"]
